import math
import matplotlib.pyplot as plt
import numpy as np

def Tsym(SF, BW):
    return (2**SF)/BW

def nPHY(payloadLength):
    CR = 1
    SF = 7
    CRC = 1
    DE = 0
    PL = payloadLength
    return 8 + max(math.ceil((28 + 8*PL + 16*CRC - 4*SF)/(4*(SF - 2*DE)))*(CR + 4), 0)

def Ttx(payloadLength):
    return 12.54 + nPHY(payloadLength)
#print(nPHY(1))
#print(Ttx(242))

# print(Tsym(7, 125000.0))
# print(Tsym(7, 125000.0)*nPHY(242)*0.01254)
# print(nPHY(242))

def Iavg(mins, sending):
    #all values in ms and mA
    if (sending):
        Times = [168.2, 83.8, 0, 983.3, 12.29, 987.7, 1.28, 147.4, 268.0, 38.6]
        Currents = [22.1, 13.3, 0, 27.0, 28.1, 27.1, 35.0, 13.2, 21.0, 13.3]
    else:
        Times = [168.2, 83.8, 0, 0, 0, 0, 0, 147.4, 268.0, 38.6]
        Currents = [22.1, 13.3, 0, 0, 0, 0, 0, 13.2, 21.0, 13.3]
    Tnotif = mins*50.160
    Tact = 0.0
    for val in Times:
        Tact += val
    Tsleep = Tnotif - Tact
    SleepCur = Tsleep * (12) #45 microAmps sleep current

    Pavg_ = 0.0
    for i in range(0, len(Times)):
        Pavg_ += (Times[i]*Currents[i])
    Pavg_ += SleepCur
    
    return (Pavg_ / Tnotif)*0.001 #mA



def energyCost(sending):
    if (sending):
        avgcurrent = Iavg(1, True)*0.001
        print(avgcurrent)
    else:
        avgcurrent = Iavg(1, False)*0.001
    V = 5
    Tnotif = 50.160
    # mJ =      milliamps * volts * seconds
    energyCost = avgcurrent * 3.6 * Tnotif
    return energyCost #/ (242*8)



def lifeTime(sending):
    if (sending):
        iavg = Iavg(1, True) #ma
    else:
        iavg = Iavg(1, False) #ma
    batteryCap = 2400 #mah
    return batteryCap / iavg #hours

# print("Iavg_unacked sending: {0}".format(Iavg(1, True)))
# print("Energy: {0}".format(energyCost(True)))
# print("Lifetime (days): {0}".format(lifeTime(True)/24))
# print("Iavg_unacked not sending: {0}".format(Iavg(1, False)))
# print("Energy: {0}".format(energyCost(False)))
# print("Lifetime (days): {0}".format(lifeTime(False)/24))
Results = [0.0]*101


for i in range(0, 101):
    Esending = (100-i)*0.01
    EnotSending = i*0.01
    mins = 10.0
    Results[i] += Iavg(mins,True)*Esending
    Results[i] += Iavg(mins, False)*EnotSending

Results = Results[::-1] #Reverse the list


lifetime = np.array([(2400 / x)/24 for x in Results]) #/24 hours in a day
lifetime2 = np.array([(4800 / x)/24 for x in Results]) #/24 hours in a day
t = np.array(range(0,101))

#print("Sending all packets: {0} days".format(lifeTime[0]))
#print("Sending every other packet: {0} days".format(lifeTime[50]))


plt.plot(t,lifetime)
#plt.plot(t,lifetime2)
plt.title('Battery lifetime when reducing amount of sent packets for 10 min duty cycle\n')
plt.xlabel('Percentage of packets not sent\n')
plt.ylabel('Battery lifetime (days)\n')
plt.show()

print(energyCost(True))