def connect(self, app_eui, app_key):
    """
    Connect device to LoRa.
    Set the socket and lora instances.
    """

    app_eui = unhexlify(app_eui)
    app_key = unhexlify(app_key)

    # Disable blue blinking and turn LED off
    LED.heartbeat(False)
    LED.off()

    # Initialize LoRa in LORAWAN mode
    self.lora = LoRa(mode = LoRa.LORAWAN)

    # Join a network using OTAA (Over the Air Activation)
    self.lora.join(activation = LoRa.OTAA, auth = (app_eui, app_key), timeout = 0) #login for TheThingsNetwork see here: https://www.thethingsnetwork.org/forum/t/lopy-otaa-example/4471

    # Wait until the module has joined the network
    count = 1
    while not self.lora.has_joined():
      LED.blink(1, 2.5, 0xff0000)
      print("Trying to join LoraWAN with OTAA: " ,  count)
      count = count + 1
      sleep(2.5)

    print ("LoraWAN joined! ")
    # save the LoRaWAN connection state
    self.lora.nvram_save()



  def send(self, data):
    """
    Send data over the network.
    """
    # Initialize LoRa in LORAWAN mode
    self.lora = LoRa(mode = LoRa.LORAWAN)
    # restore the LoRaWAN connection state
    self.lora.nvram_restore()

    # Create a LoRa socket
    print("Create LoRaWAN socket")
    self.s = socket.socket(socket.AF_LORA, socket.SOCK_RAW)

    # Set the LoRaWAN data rate
    self.s.setsockopt(socket.SOL_LORA, socket.SO_DR, 5)

    # Make the socket non-blocking
    self.s.setblocking(False)

    try:
      self.s.send(data)
      LED.blink(2, 0.1, 0x00ff00)
      print("Sending data:")
      print(data)
      # save the LoRaWAN connection state
      self.lora.nvram_save()
    except OSError as e:
      if e.errno == 11:
        print("Caught exception while sending")
        print("errno: ", e.errno)