import onewire
from machine import Pin

class TempSensor:

    def __init__(self):
        self.tempSensor = onewire.DS18X20(onewire.OneWire(Pin('P23', mode=Pin.OUT)))
    
    def readTemp(self):
        temperature = None
        while (temperature == None or int(temperature) == 85):
            temperature = self.tempSensor.read_temp_async()
            self.tempSensor.start_convertion()
        return  "%.2f" % temperature

class Lora:

    def __init__(self, dev_eui, app_eui, app_key):
        pycom.heartbeat(False) # disable the blue blinking
        pycom.rgbled(0x000000) #LED off
        pycom.wifi_on_boot(False)
        print("Setting up LoRaWAN...")
        self.lora = LoRa(mode=LoRa.LORAWAN)
        self.dev_eui = binascii.unhexlify(dev_eui)
        self.app_eui = binascii.unhexlify(app_eui)
        self.app_key = binascii.unhexlify(app_key)
        self.lora.add_channel(0, frequency=868100000, dr_min=0, dr_max=5)
        self.lora.add_channel(1, frequency=868100000, dr_min=0, dr_max=5)
        self.lora.add_channel(2, frequency=868100000, dr_min=0, dr_max=5)
    
    def connect(self, blocking = False, timeout = 0, function = None):
        print("Connecting...")
        self.lora.join(activation=LoRa.OTAA, auth=(self.dev_eui, self.app_eui, self.app_key), timeout=0)

        if timeout == 0:
            while not self.lora.has_joined():
                if function == None:
                    time.sleep(2.5)
                else:
                    function()
        else:
            for x in range(timeout):
                if self.lora.has_joined():
                    break
                if function == None:
                    time.sleep(2.5)
                else:
                    function()
            
        if not self.lora.has_joined():
            return False

        for i in range(3, 16):
            self.lora.remove_channel(i)

        self.s = socket.socket(socket.AF_LORA, socket.SOCK_RAW)

        # set the LoRaWAN data rate
        self.s.setsockopt(socket.SOL_LORA, socket.SO_DR, 5)

        # make the socket non-blocking
        self.s.setblocking(blocking)
        print("Connected!")
    
        return True


    def callback(trigger, handler):
        self.lora.callback(trigger=trigger, handler=handler)

    def send(self, data):
        print("Sending: {0}".format(data))
        self.s.send(data)

    def recv(self, length):
        return self.s.recvfrom(length)
    
    def save_state(self):
        print("Saving LoRA state to NVRAM")
        self.lora.nvram_save()

    def restore_state(self, restoredState):
        print("Restoring LoRA state from NVRAM")
        self.lora = restoredState

    def turnOffUnwantedRadios(self):
        wlan = WLAN()
        wlan.deinit()
        server = Server()
        server.deinit()
        bluetooth = Bluetooth()
        bluetooth.deinit()
        lte = LTE()
        lte.deinit()

