import machine, time, pycom, socket, struct, sys, _thread
from network import LoRa

pycom.heartbeat(False)
pycom.rgbled(0x000000)

uart1 = UART(1, 115200, bits=8, parity=None, stop=1)
uart1.init(baudrate=115200, bits=8, parity=None, stop=1)

# Open a LoRa Socket, use rx_iq to avoid listening to our own messages
lora = LoRa(mode=LoRa.LORA, tx_iq=True)
lora_sock = socket.socket(socket.AF_LORA, socket.SOCK_RAW)
lora_sock.setblocking(False)

initial_format = b'b'

def setLopyLight(color):
    pycom.rgbled(color)

def sleep(t):
    time.sleep(t)

def getFromPi():
    id = None
    while True:
        if uart1.any():
            setLopyLight(0x00FF00)
            receiving = uart1.read().decode('utf-8')
            if (id == None):
                #get id from the first message sent from the pi
                id = int(receiving.split("=")[1])
            sendToLopy(id, receiving)
            if (receiving == "sending done"):
                break
        sleep(1)

def sendToLopy(id, codeToSend):
    #get length of the string to send and concatinate the initial format ('b') with len string times 's'
    packet_format = initial_format.decode('utf-8') + '%ss' % (len(codeToSend),)
    packed = struct.pack(packet_format, id, codeToSend)
    lora_sock.send(packed)

def getFromLopy():
    while True:
        recv_packet = lora_sock.recv(1024)
        if (len(recv_packet) > 0):
            setLopyLight(0x00FF00)
            packet_format = initial_format.decode('utf-8') + '%ss' % (len(recv_packet)-(len(initial_format)),)
            device_id, message = struct.unpack(packet_format, recv_packet)
            toSend = str(device_id) + ":" + message.decode('utf-8')
            print(toSend)
            sendToPi(toSend)
            sleep(1)
            setLopyLight(0x000000)
        sleep(1)

def sendToPi(data):
    uart1.write(data)

def changeLopyState():
    while True:
        getFromPi()
        print("Done getting from lopy")

def registerMeasurements():
    getFromLopy()

_thread.start_new_thread(changeLopyState, ())    
_thread.start_new_thread(registerMeasurements, ())
#getCodeFromPi()
#getResponse()

