import time, binascii
from machine import Timer, Pin, I2C

#name = Register, numBytes
    #powerAcc = 3, 6
    #voltage = 7, 2
    #current = 19, 2
    #power = 23, 4

def getVoltage(a):
    first = a[0]
    second = a[1]
    first = first<<8
    result = first | second
    #print("Vb",32 * (result/(2**16)))
    return 32 * (result/(2**16))

def getCurrent(a):
    first = a[0]
    second = a[1]
    first = first<<8
    result = first | second
    return 25 * (result/(2**16))

def getPowerAcc(a):
    first = a[0]<<40
    second = a[1]<<32
    third = a[2]<<24
    forth = a[3]<<16
    fifth = a[4]<<8
    sixth = a[5]
    result = first | second | third | forth | fifth |sixth
    return result

def getCount(a):
    first = a[0]<<16
    second = a[1]<<8
    third = a[2]
    result = first | second | third
    return result


def getPower(a):
    PowerFSR = ((3.2))/0.004
    first = a[0]<<24
    second = a[1]<<16
    third = a[2]<<8
    forth = a[3]
    result = first | second | third | forth
    result = result >>4
    pprop = result/(2**28)
    return PowerFSR * pprop



p_one = Pin('P21', mode=Pin.IN, pull=Pin.PULL_UP)
p_two = Pin('P22', mode=Pin.IN, pull=Pin.PULL_UP)
p_three = Pin('P23', mode=Pin.IN, pull=Pin.PULL_UP)

chrono = Timer.Chrono()
i2c = I2C(0, pins=('P9', 'P10'))
i2c.init(I2C.MASTER, baudrate=9600)
addr = i2c.scan()[0]
logFile = open("bytesTestLong2.csv", "a")
logFile.write("Number of samples, Accumulated Power, Time spent (s) \n")
logFile.close()
accumulatedPower = 0
while(p_one() == 1):
    while(p_two() == 0):
        time.sleep(0.05) #program not started yet. wait
        if(p_one() == 0 and p_two() == 0):
            break
    if(p_one() == 0):
        break
    print("Starting measurements")
    i2c.writeto(addr, 0x00, stop=True) #Refresh
    numSamples = 0 #number of samples
    while (p_two() == 1):
        if (p_one() == 0):
            break
        while(p_three() == 0):
            if(p_one() == 0):
                break
            time.sleep(0.05)
        chrono = Timer.Chrono() #timer
        chrono.start() #start timer
        logFile = open("bytesTestLong2.csv", "a")
        while(p_three() == 1):
            #print(accumulatedPower)
            data = i2c.readfrom_mem(addr, 23, 4) #read data from power register
            power = getPower(data) #calculate the power
            accumulatedPower += power # add the power to the accumulated power
            i2c.writeto(addr, 0x00, stop=True) #Refresh
            time.sleep(0.0001)
            numSamples += 1 # add a sample to the number of samples
        chrono.stop()
        #simulation for one packet size if finished. Write results to log file / print
        print("-----------------------------------------------------------")
        print("Accumulated Power: {0}".format(accumulatedPower))
        print("Number of samples: {0}".format(numSamples))
        print("Time: {0}".format(chrono.read()))
        print("-----------------------------------------------------------")
        print(" ")
        result = "{0}, {1}, {2}\n".format(numSamples, accumulatedPower, chrono.read())
        logFile.write(result)
        logFile.close()
        accumulatedPower = 0
        numSamples = 0
        break
#logFile.close()
print("Simulation done")
