import time, binascii
from machine import Timer, Pin, I2C

#name = Register, numBytes
    #powerAcc = 3, 6
    #voltage = 7, 2
    #current = 19, 2
    #power = 23, 4

def getVoltage(a):
    first = a[0]
    second = a[1]
    first = first<<8
    result = first | second
    return 32 * (result/(2**16))

def getCurrent(a):
    first = a[0]
    second = a[1]
    first = first<<8
    result = first | second
    return 25 * (result/(2**16))

def getPowerAcc(a):
    first = a[0]<<40
    second = a[1]<<32
    third = a[2]<<24
    forth = a[3]<<16
    fifth = a[4]<<8
    sixth = a[5]
    result = first | second | third | forth | fifth |sixth
    return result

def getCount(a):
    first = a[0]<<16
    second = a[1]<<8
    third = a[2]
    result = first | second | third
    return result


def getPower(a):
    PowerFSR = ((3.2))/0.004
    first = a[0]<<24
    second = a[1]<<16
    third = a[2]<<8
    forth = a[3]
    result = first | second | third | forth
    result = result >>4
    pprop = result/(2**28)
    return PowerFSR * pprop



p_one = Pin('P21', mode=Pin.IN, pull=Pin.PULL_UP)

chrono = Timer.Chrono()
i2c = I2C(0, pins=('P9', 'P10'))
i2c.init(I2C.MASTER, baudrate=9600)
addr = i2c.scan()[0]
logFile = open("energyTest.csv", "a")
logFile.write("Number of samples, Accumulated Current, Energy, Time spent (s) \n")
logFile.close()
accumulatedCurrent = 0
numberOfRuns = 10
data = i2c.readfrom_mem(addr, 19, 2) #read data from current register
current = getCurrent(data) #calculate the current
print(current)

def writeToFile(numSamples, averageEnergy, energy, t):
    toWrite = "{0}, {1}, {2}, {3}\n".format(numSamples,averageEnergy, energy, t)
    logFile = open("energyTest.csv", "a")
    logFile.write(toWrite)
    logFile.close()

while(numberOfRuns > 0):
    while(p_one() == 0):
        time.sleep(0.01)
    
    i2c.writeto(addr, 0x00, stop=True) #Refresh
    numSamples = 0 #number of samples
    chrono = Timer.Chrono() #timer
    chrono.start() #start timer
    while (p_one() == 1):
        if (p_one() == 0):
            break
            
        data = i2c.readfrom_mem(addr, 19, 2) #read data from current register
        current = getCurrent(data) #calculate the current
        accumulatedCurrent += current # add the current to the accumulated current
        i2c.writeto(addr, 0x00, stop=True) #Refresh
        time.sleep(0.0001)
        numSamples += 1 # add a sample to the number of samples
    
    #simulation for one duty cycle (Tnotif) is finished. Write results to log file / print
    chrono.stop()
    timeUsed = chrono.read()
    averageEnergy = accumulatedCurrent / numSamples
    energy = averageEnergy * 5 * chrono.read()
    print("-----------------------------------------------------------")
    print("Accumulated Current: {0}".format(accumulatedCurrent))
    print("Average Current: {0}".format(averageEnergy))
    print("Number of samples: {0}".format(numSamples))
    print("Energy: {0}".format(energy))
    print("Time: {0}".format(timeUsed))
    print("-----------------------------------------------------------")
    print(" ")
    writeToFile(numSamples,averageEnergy,energy,timeUsed)
    accumulatedPower = 0
    numSamples = 0
    numberOfRuns -= 1
        
print("Simulation done")
